package GetArchives::Tag;

use strict;
use MT::Util qw( archive_file_for );

sub hdlr_get_archives {
    my ( $ctx, $args ) = @_;
    my $blog = $ctx->stash('blog');
    my $at   = $blog->archive_type;
    return '' if !$at || $at eq 'None';
    my $arg_at;
    if ( $arg_at = $args->{type} || $args->{archive_type} ) {
        $at = $arg_at;
    } else {
        $at = 'Monthly';
    }
    return hdlr_get_entries(@_) if ( $at eq 'postbypost');

    my $archiver = MT->publisher->archiver($at);
    return '' unless $archiver;

    my %args;
    my $sort_order
        = lc( $args->{sort_order} || '' ) eq 'ascend' ? 'ascend' : 'descend';
    $args{sort} = 'authored_on';
    $args{direction} = $sort_order;

    my $res     = '';
    my $i       = 0;
    my $n       = $args->{limit};

    my $order = $sort_order eq 'ascend' ? 'asc' : 'desc';
    my $group_iter = $archiver->archive_group_iter( $ctx, $args );
    return $ctx->error( MT->translate("Group iterator failed.") )
        unless defined($group_iter);

    my ( $cnt, %curr ) = $group_iter->();

    while ( defined($cnt) ) {

        $i++;
        my ( $next_cnt, %next ) = $group_iter->();
        my $last;
        $last = 1 if $n && ( $i >= $n );
        $last = 1 unless defined $next_cnt;

        my ( $start, $end );
        if ( $archiver->date_based ) {
            ( $start, $end ) = ( $curr{'start'}, $curr{'end'} );
        }
        else {
            my $entry = $curr{entries}->[0] if exists( $curr{entries} );
            ( $start, $end ) = ( ref $entry ? $entry->authored_on : "" );
        }

        my $entry;
        my $cat;
        my $author = $ctx->stash('author');
        my $arch = $blog->archive_url;
        $arch .= '/' unless $arch =~ m!/$!;
        $arch .= archive_file_for( $entry, $blog, $at, $cat, undef, $start, $author );
        $arch = MT::Util::strip_index( $arch, $blog ) unless $args->{with_index};
        my $title = $archiver->archive_title( $ctx, $start );
        my $archive_count = '';
        if ( $args->{show_post_count}) {
            my $e = $archiver->archive_group_entries( $ctx, %curr ) if $archiver->group_based;
            my @entries = @$e if ref($e) eq 'ARRAY';
            $archive_count = scalar @entries;
        }
        $res .= qq{<li><a title="$title" href="$arch">$title</a>$archive_count</li>};
        last if $last;
        ( $cnt, %curr ) = ( $next_cnt, %next );
    }

    $args->{before} . $res . $args->{after};
}

sub hdlr_get_entries {
    my ( $ctx, $args ) = @_;
    my $blog = $ctx->stash('blog');

    my %args;
    my $sort_order
        = lc( $args->{sort_order} || '' ) eq 'ascend' ? 'ascend' : 'descend';
    $args{sort} = 'authored_on';
    $args{direction} = $sort_order;
    my $order = $sort_order eq 'ascend' ? 'asc' : 'desc';
    $args{limit} = $args->{limit} if $args->{limit};

    my $entry_class = 'entry';
    my @entries = MT->model($entry_class)->load( { blog_id => $blog->id }, \%args );
    my $res;
    for my $entry (@entries) {
        my $title = $entry->title;
        my $link = $entry->permalink;
        $res .= qq{<li><a title="$title" href="$link">$title</a></li>};
    }
    $args->{before} . $res . $args->{after};
}

1;
